<?php

require __DIR__ . '/class.ISPConfigDebian10OS.inc.php';

/**
 * Description of class
 *
 * @author croydon
 */
class ISPConfigDebian11OS extends ISPConfigDebian10OS {
	protected function addBusterBackportsRepo() {
		// not in bullseye
	}

	protected function getRoundcubePackages() {
		return array(
			'roundcube',
			'roundcube-core',
			'roundcube-mysql',
			'roundcube-plugins'
		);
	}

	protected function getPackagesToInstall($section) {
		$packages = parent::getPackagesToInstall($section);

		if($section === 'base') {
			$key = array_search('php-gettext', $packages, true);
			if($key !== false) {
				unset($packages[$key]);
			}
			$packages[] = 'jailkit';
		} elseif($section === 'ftp_stats') {
			// prepare paths
			ISPConfigLog::info('Symlinking webalizer to use awffull.');
			mkdir('/etc/webalizer', 0755);
			chmod('/etc/webalizer', 0755);
			symlink('/etc/awffull/awffull.conf', '/etc/webalizer/webalizer.conf');
			symlink('/usr/bin/awffull', '/usr/bin/webalizer');

			$key = array_search('webalizer', $packages, true);
			if($key !== false) {
				unset($packages[$key]);
			}
			$packages[] = 'awffull';
		}

		return $packages;
	}

	protected function isStableSupported() {
		return false;
	}

	protected function shallCompileJailkit() {
		return false;
	}

	protected function getMySQLUserQueries($mysql_root_pw) {
		$escaped_pw = preg_replace('/[\'\\\\]/', '\\$1', $mysql_root_pw);
		$queries = array(
			'DELETE FROM mysql.user WHERE User=\'\';',
			'DELETE FROM mysql.user WHERE User=\'root\' AND Host NOT IN (\'localhost\', \'127.0.0.1\', \'::1\');',
			'DROP DATABASE IF EXISTS test;',
			'DELETE FROM mysql.db WHERE Db=\'test\' OR Db=\'test\\_%\';',
			'SET PASSWORD FOR \'root\'@\'localhost\' = PASSWORD(\'' . $escaped_pw . '\');',
			'FLUSH PRIVILEGES;'
		);

		return $queries;
	}

	protected function installPHPMyAdmin($mysql_root_pw) {
		if(!ISPConfig::shallInstall('web') || !ISPConfig::shallInstall('pma')) {
			return;
		}

		$cmd = 'APP_PASS="' . ISPConfigFunctions::generatePassword(15) . '"' . "\n";
		$cmd .= 'ROOT_PASS="' . $mysql_root_pw . '"' . "\n";
		$cmd .= 'APP_DB_PASS="' . ISPConfigFunctions::generatePassword(15) . '"' . "\n";
		$cmd .= 'echo "phpmyadmin phpmyadmin/dbconfig-install boolean true" | debconf-set-selections 2>&1' . "\n";
		$cmd .= 'echo "phpmyadmin phpmyadmin/app-password-confirm password $APP_PASS" | debconf-set-selections 2>&1' . "\n";
		$cmd .= 'echo "phpmyadmin phpmyadmin/mysql/admin-user string root" | debconf-set-selections 2>&1' . "\n";
		$cmd .= 'echo "phpmyadmin phpmyadmin/mysql/admin-pass password $ROOT_PASS" | debconf-set-selections 2>&1' . "\n";
		$cmd .= 'echo "phpmyadmin phpmyadmin/mysql/app-pass password $APP_DB_PASS" | debconf-set-selections 2>&1' . "\n";
		$cmd .= 'echo "phpmyadmin phpmyadmin/reconfigure-webserver multiselect apache2" | debconf-set-selections 2>&1' . "\n";
		$result = $this->exec($cmd);
		if($result === false) {
			throw new ISPConfigOSException('Command ' . $cmd . ' failed.');
		}

		$this->installPackages('phpmyadmin');
	}

	protected function installMailman($host_name) {
		ISPConfigLog::info('ISPConfig does not yet support mailman3 and mailman2 is no longer available in Debian 11.', true);
		return;
	}

	protected function getSystemPHPVersion() {
		return '7.4';
	}
}
